# vim: set sw=4 ts=4 et nu:

# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/

Name:               OpenOctaveMidi-unstable
Version:            2012.1.0+20120403
%define pkg_version 2012-04-03
%define dversion    2012.1.beta1
Release:            2.1
Summary:            Open Octave Studio
## git://git.openoctave.org/oom.git
Source:             oom-%{pkg_version}.tar.bz2
Source1:            oom_icon_root_32x32.png
Source2:            oom_root-mode.desktop
#PATCH-FIX-UPSTREAM oom-2011.3.1_gcc47.patch avvissu@yandex.ru -- Fix build with gcc47
Patch0:             oom-2012-04-03_gcc47.patch
URL:                http://openoctave.org
Group:              Productivity/Multimedia/Sound/Midi
License:            GPL-2.0+
BuildRoot:          %{_tmppath}/build-%{name}-%{version}
BuildRequires:      libgig-devel
BuildRequires:      liblscp-devel
BuildRequires:      liblinuxsampler-devel
BuildRequires:      libqt4-devel >= 4.3.0
BuildRequires:      gtk2-devel
BuildRequires:      alsa-devel >= 0.9.0
BuildRequires:      libsndfile-devel >= 1.0.0
BuildRequires:      libsamplerate-devel >= 0.1.0
BuildRequires:      libuuid-devel >= 0.0.1
BuildRequires:      jack-devel >= 1.9.5
BuildRequires:      gcc-c++ cmake make glibc-devel pkgconfig
BuildRequires:      update-desktop-files
%ifarch armv6hl
BuildRequires:      -Mesa-libEGL-devel
%endif
Conflicts:          OpenOctaveMidi
Requires:           alsa-plugins-jack
Requires:           jack
Recommends:         %{name}-lang
Recommends:         qjackctl

%description
Digital Audio Workstation (DAW).


%package lang
Summary:            Languages for package %{name}
Group:              System/Localization
Requires:           %{name} = %{version}
Provides:           %{name}-lang-all = %{version}
Supplements:        packageand(bundle-lang-other:%{name})
BuildArch:          noarch
Conflicts:          OpenOctaveMidi-lang

%description lang
Provides translations to the package %{name}                                                                                   

%prep
%setup -q -n oom
%if 0%{?suse_version} > 1140
%patch0 -p1
%endif

%build
%__install -d build
pushd build
cmake \
    -DCMAKE_VERBOSE_MAKEFILE=TRUE \
    -DCMAKE_INSTALL_PREFIX="%{_prefix}" \
    -DCMAKE_SKIP_RPATH=TRUE \
    -DCMAKE_BUILD_WITH_INSTALL_RPATH=FALSE \
    ..
%__make %{?_smp_mflags}
popd

%install
pushd build
%makeinstall
popd

# upstream installs a 32x32 icon in a 64x64 directory:
%__install -d "%{buildroot}%{_datadir}/icons/hicolor/32x32/apps"
%__mv "%{buildroot}%{_datadir}/icons/hicolor"/{64x64,32x32}/"apps/oom_icon.png"

# OOMidi Root Mode
install -D -m 0644 %{S:1} %{buildroot}%{_datadir}/icons/hicolor/32x32/apps/oom_icon_root.png
install -D -m 0644 %{S:2} %{buildroot}%{_datadir}/applications/oom_root-mode.desktop

%__rm -rf "%{buildroot}%{_datadir}/doc"

%suse_update_desktop_file -r oom AudioVideo Audio Midi AudioVideoEditing

L="$PWD/%{name}.lang"
echo -n >"$L"
P="%{_datadir}/oom-%{dversion}/locale"
pushd "%{buildroot}$P"
/bin/ls -1 oom_*.qm | while read qm; do
    l="${qm#oom_}"
    l="${l%.qm}"
    echo "%lang($l) $P/$qm" >>"$L"
done
popd

%clean
%{?buildroot:%__rm -rf "%{buildroot}"}

%files
%defattr(-,root,root)
%doc AUTHORS COPYING README*
%{_bindir}/oomidi
%{_bindir}/oostudio
%{_datadir}/applications/oom*.desktop
%{_datadir}/icons/*/*/apps/oom_icon*.png
%doc %{_mandir}/man1/oomidi.1*
%{_datadir}/mime/packages/oom.xml
%dir %{_datadir}/oom-%{dversion}
%{_datadir}/oom-%{dversion}/instruments
%dir %{_datadir}/oom-%{dversion}/locale
%{_datadir}/oom-%{dversion}/plugins
%{_datadir}/oom-%{dversion}/pybridge
%{_datadir}/oom-%{dversion}/scripts
%{_datadir}/oom-%{dversion}/templates
%{_datadir}/oom-%{dversion}/utils

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Sat Oct 18 2014 avvissu@yandex.ru
- Fix build error (add oom-2012-04-03_gcc47.patch)
- OOMidi requires the root privilege for accessing the RTC device
  with higher resolution:
  * add Root Mode (oom_root-mode.desktop)
- add Requires: alsa-plugins-jack jack
* Mon Apr 16 2012 pascal.bleser@opensuse.org
- initial version (2012.1.0+20120403)
